@@ -3,17 +3,17 @@ package org.gcube.portlets.user.td.columnwidget.client.dimension;
 import java.util.ArrayList;
 
 import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
-import org.gcube.portlets.user.td.columnwidget.client.properties.TabResourceProperties;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.TabResourceProperties;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.core.client.GWT;
